Method: Roi#wait_until_not_displayed?

Defined in:
lib/roi/roi.rb

#wait_until_not_displayed?(timeout, args = {}) ⇒ Boolean

Public: Returns true if the given Roi disappears within the given time.

api_wait_till_<ROI TYPE>_not_displayed?

timeout - Integer total milliseconds to allow before timing out. key - String key press to trigger evaluation (default: nil).

If default, no key will be pressed.

delay - Integer total milliseconds to delay before starting evaluation (default: 0). scale - Boolean if the larger image should be scaled to the size of the smaller image (default: false).

Applies to image ROIs only.

priority - Symbol evaluation priority used to throttle CPU usage (default: :normal):

:critical   - Sleep 10 ms between intensive tasks (USE SPARINGLY)
:high       - Sleep 100 ms between intensive tasks
:normal     - Sleep 1 second between intensive tasks
:low        - Sleep 10 seconds between intensive tasks
:background - Sleep 1 minute between intensive tasks (USE SPARINGLY)

log_every - Integer total milliseconds between logs (default: 1000).

Returns a Boolean true if the Roi disappears before the timeout, otherwise false.

Returns:

  • (Boolean)


307
308
309
310
311
312
# File 'lib/roi/roi.rb', line 307

def wait_until_not_displayed?(timeout, args={})
  logger.info("Waiting #{timeout} ms until #{self.class.name} is not displayed")
  args[:timeout] = timeout
  args[:expected] = false
  displayed?(args)
end